#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-engine
version:              0.5.3.1
visibility:           public
id:                   pandoc-lua-engine-0.5.3.1-GLZ8GD3X2efaPBmpkWszD
key:                  pandoc-lua-engine-0.5.3.1-GLZ8GD3X2efaPBmpkWszD
license:              GPL-2.0-or-later
copyright:            © 2006-2024 John MacFarlane, 2017-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  9c6fdfeb1f450a99cd1b3a35038d90ab
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Documentation
    Text.Pandoc.Lua.Engine Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init Text.Pandoc.Lua.Module
    Text.Pandoc.Lua.Marshal.Chunks Text.Pandoc.Lua.Marshal.CommonState
    Text.Pandoc.Lua.Marshal.Context Text.Pandoc.Lua.Marshal.Format
    Text.Pandoc.Lua.Marshal.ImageSize
    Text.Pandoc.Lua.Marshal.LogMessage
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.Image
    Text.Pandoc.Lua.Module.JSON Text.Pandoc.Lua.Module.Log
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Path Text.Pandoc.Lua.Module.Scaffolding
    Text.Pandoc.Lua.Module.Structure Text.Pandoc.Lua.Module.System
    Text.Pandoc.Lua.Module.Template Text.Pandoc.Lua.Module.Text
    Text.Pandoc.Lua.Module.Types Text.Pandoc.Lua.Module.Utils
    Text.Pandoc.Lua.Orphans Text.Pandoc.Lua.PandocLua
    Text.Pandoc.Lua.Run Text.Pandoc.Lua.SourcePos
    Text.Pandoc.Lua.Writer.Classic Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.5.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.5.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.5.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.5.3.1-GLZ8GD3X2efaPBmpkWszD
depends:
    aeson-2.2.2.0-7c2B0clV8yIEXobemFKLly base-4.18.2.1
    bytestring-0.11.5.3 citeproc-0.13.0.1-L2TmJk5ddPA5tdNxr84uF7
    containers-0.6.7 crypton-1.0.5-8C2I1Rf6QReJKslsE3zXuF
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    doclayout-0.5.0.3-19wYOTkFhQj7ga4Iw88MWl
    doctemplates-0.11.0.1-FBr6g8Dro3v78a2tWYURkt exceptions-0.10.7
    hslua-2.5.0-FtrqpPN2t6aGCc933PIrX1
    hslua-module-doclayout-1.2.1.1-EOP17jo1ID716shT3dDCf3
    hslua-module-path-1.2.0-EbxO8eXw7vTEQmgab0xUj0
    hslua-module-system-1.3.0-HXPH6056ChQLTFjFlCK8Vt
    hslua-module-text-1.2.0-JN7OqiX70V4Xix6ksAgDr
    hslua-module-version-1.2.0.1-JIlCD72cZYZ1tx8CTvr9hk
    hslua-module-zip-1.2.1-ADxhPrILZdgJz9mmsE5kcR
    hslua-repl-0.1.2-HHiM9BIUGFSIxW3IkeSjfU
    lpeg-1.1.0.1-D8lKW4xVT6aJ8EeXqSZcld mtl-2.3.1
    pandoc-3.10.2-CqQbrIW25LN80N7CBanudD
    pandoc-lua-marshal-0.3.2.1-FTOt04eY5Fh6c4qxkcSuCB
    pandoc-types-1.23.1.2-2nGSR2cTzYVBKLlt019CRQ parsec-3.1.16.1
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

